# gebaSpike
This is a Python Package created to spike sort in-vivo electrophysiology data recorded using DaqUSB (or converted to the Tint format). This program is minimalistic and was essentially just created to speed up the time I spend sorting/cleaning spikes.

# Requirements
Since it utilizes PyQt5 as the GUI framework it should be available to a wide variety of Python versions and Operating Systems. However it was only tested on Python 3.7 with Windows 10. I do recommend using the latest version of Python as it makes it easy to download some of these C++ based dependencies. 

# Project Documentation
[![gebaSpike: Tutorial](https://geba.s3.amazonaws.com/media/projects/gebaspike-python-spike-sorting-software-tintaxona-data/geba_title.png)](https://www.youtube.com/watch?v=QBGdaNWtnZg)


- [Installation](https://geba.technology/project/gebaspike-python-spike-sorting-software-tintaxona-data)
- [User Guide](https://geba.technology/project/gebaspike-python-spike-sorting-software-tintaxona-data-gebaspike-user-guide)

# Authors
* **Geoff Barrett** - [Geoff’s GitHub](https://github.com/GeoffBarrett)

# License

This project is licensed under the GNU  General  Public  License - see the [LICENSE.md](../master/LICENSE) file for details
